@@ -34,7 +34,7 @@ import db
 import gutils
 import initialize
 import main_treeview
-import imp
+import importlib
 
 log = logging.getLogger("Griffith")
 
@@ -285,7 +285,7 @@ def get_from_web(self):
         if self.debug_mode:
             log.debug('reloading %s', plugin_name)
             import sys
-            imp.reload(sys.modules[plugin_name])
+            importlib.reload(sys.modules[plugin_name])
         self.search_movie = plugin.SearchPlugin()
         self.search_movie.config = self.config
         self.search_movie.locations = self.locations
@@ -303,8 +303,6 @@ def get_from_web(self):
                 self.search_movie.title = title
         # check if internet connection is available
         try:
-            #urllib2.urlopen("http://www.google.com")
-            urllib.request.urlopen(self.search_movie.url)
             if self.search_movie.search_movies(self.widgets['add']['window']):
                 self.search_movie.get_searches()
             if len(self.search_movie.ids) == 1 and o_title and title:
@@ -312,7 +310,7 @@ def get_from_web(self):
                 if self.search_movie.remove_accents:
                     self.search_movie.title = gutils.remove_accents(title, 'utf-8')
                 else:
-                    self.search_movie.title = str(title, 'utf-8')
+                    self.search_movie.title = title.str('utf-8')
                 if self.search_movie.search_movies(self.widgets['add']['window']):
                     self.search_movie.get_searches()
             self.show_search_results(self.search_movie)
