@@ -22,6 +22,7 @@ __revision__ = '$Id$'
 # GNU General Public License, version 2 or later
 
 import gettext
+import locale
 import logging
 import math
 import os
@@ -141,12 +142,12 @@ def gui(self):
 
 
 def i18n(self, location):
-    gettext.bindtextdomain('griffith', location)
-    gettext.textdomain('griffith')
-    #Gtk.glade.bindtextdomain('griffith', location)
-    #Gtk.glade.textdomain('griffith')
-    gettext.install('griffith', location)
-
+    app = 'griffith'
+    locale.setlocale(locale.LC_ALL, os.environ['LANG'])
+    locale.bindtextdomain(app, location)
+    gettext.bindtextdomain(app, location)
+    gettext.textdomain(app)
+    gettext.install(app, location)
 
 def toolbar(self):
     """if toolbar is hide in config lets hide the widget"""
