@@ -30,6 +30,7 @@ import tempfile
 import threading
 import time
 from urllib.request import *
+from urllib.parse import quote
 from gi.repository import Gtk
 import gutils
 import urllib.request, urllib.error, urllib.parse
@@ -72,7 +73,7 @@ class Movie(object):
     page = None
     url = None
     image_url = None
-    encode = 'iso-8859-1'
+    encode = 'utf-8'
     fields_to_fetch = []
     progress = None
     useurllib2 = False
@@ -196,7 +197,7 @@ class Movie(object):
         try:
             if retriever.exception is None:
                 if retriever.html:
-                    ifile = open(retriever.html[0], "r", encoding=self.encode)
+                    ifile = open(retriever.html[0], "r", encoding=self.encode, errors='replace')
                     try:
                         data = ifile.read()
                     finally:
@@ -337,6 +338,8 @@ class SearchMovie(object):
     def open_search(self, parent_window, destination=None):
         self.titles = [""]
         self.ids = [""]
+
+        self.title = quote(self.title)
         if self.url.find('%s') > 0:
             self.url = self.url % self.title
             self.url = self.url.replace(' ', '%20')
@@ -344,10 +347,6 @@ class SearchMovie(object):
             if not self.usepostrequest:
                 tempstr = self.url + self.title
                 self.url = tempstr.replace(' ', '%20')
-        #try:
-        #    url = self.url.encode(self.encode)
-        #except UnicodeEncodeError:
-        #    url = self.url.encode('utf-8')
         url = self.url
         self.progress.set_data(parent_window, _("Searching"), _("Wait a moment"), True)
         if self.usepostrequest:
@@ -455,6 +454,7 @@ def urlretrieve(url, filename=None, reporthook=None, data=None):
     global _uaurlopener
     if not _uaurlopener:
         _uaurlopener = UAFancyURLopener()
+    log.debug("url :%s:", url)
     return _uaurlopener.retrieve(url, filename, reporthook, data)
 
 
@@ -503,9 +503,9 @@ class UAFancyURLopener(FancyURLopener):
         FancyURLopener.__init__(self, *args, **kwargs)
         # additional HTTP headers to work around the html file compression which
         # is used by UMTS connections. compression breaks the movie import plugins sometimes
-        self.addheaders.append(('Cache-Control', 'no-cache'))
-        self.addheaders.append(('Pragma', 'no-cache'))
-        self.addheaders.append(('Accept-Language', '%s,en;q=0.5' % get_locale()))
+        self.addheader('Cache-Control', 'no-cache')
+        self.addheader('Pragma', 'no-cache')
+        self.addheader('Accept-Language', '%s,en;q=0.5' % get_locale())
 
     def open(self, fullurl, data=None):
         # prevent blocking calls which doesn't come back
