@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id$'
+__revision__ = '$Id: PluginMovieIMDB.py 1660 2014-03-13 20:48:05Z mikej06 $'
 
-# Copyright (c) 2005-2013 Vasco Nunes, Piotr Ożarowski
+# Copyright (c) 2005-2021 Vasco Nunes, Piotr Ożarowski, Wolfgang Friebel
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,65 +21,127 @@ __revision__ = '$Id$'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-# Edited by Peter Munch-Ellingsen and Dan Johansen
-# Puplished by Dan Johansen
-
 import gutils, movie
 import string, re
+from urllib.parse import quote
 
 plugin_name         = 'IMDb'
 plugin_description  = 'Internet Movie Database'
 plugin_url          = 'www.imdb.com'
 plugin_language     = _('English')
-plugin_author       = 'Vasco Nunes, Piotr OÅ¼arowski'
+plugin_author       = 'Vasco Nunes, Piotr Ożarowski'
 plugin_author_email = 'griffith@griffith.cc'
-plugin_version      = '1.15'
+plugin_version      = '1.20'
 
 class Plugin(movie.Movie):
     def __init__(self, id):
         self.encode   = 'utf-8'
-        self.movie_id = id
-        self.url      = "http://imdb.com/title/tt%s" % self.movie_id
+        self.movie_id = quote(id)
+        self.url      = "https://www.imdb.com/title/tt%s/" % self.movie_id
 
     def initialize(self):
-        self.cast_page = self.open_page(url=self.url + '/fullcredits')
-        self.plot_page = self.open_page(url=self.url)
-        self.comp_page = self.open_page(url=self.url + '/companycredits')
-        self.tagl_page = self.open_page(url=self.url + '/taglines')
+        self.cast_page = self.open_page(url=self.url + 'fullcredits')
+        self.plot_page = self.open_page(url=self.url + 'plotsummary')
+        self.comp_page = self.open_page(url=self.url + 'companycredits')
+        self.tagl_page = self.open_page(url=self.url + 'taglines')
+        self.cert_page = self.open_page(url=self.url + 'parentalguide')
+        self.release_page = self.open_page(url=self.url + 'releaseinfo')
 
     def get_image(self):
-        tmp = gutils.trim(self.page, '<div class="poster">', '</div>')
-        image_link = gutils.trim(tmp, '<a href="', '"')
-        poster_page = self.open_page(url='http://www.imdb.com' + image_link)
-#        tmp = gutils.trim(poster_page, '<div class="photo">', '</div>')
-        self.image_url = gutils.trim(tmp, 'src="', '"')
+        self.image_url = ''
+        tmp = gutils.trim(gutils.trim(self.page, '"edges":[{"node":{"entity":{"primaryImage":', '}'), '"url":"', '"')
+        if tmp:
+            self.image_url = tmp
+        else:
+            tmp = gutils.trim(self.page, 'ipc-media--poster', '/>')
+            if tmp:
+                self.image_url = gutils.trim(tmp, 'src="', '"')
 
     def get_o_title(self):
-        self.o_title = gutils.regextrim(self.page, 'class="title-extra">', '<')
+        # it seems, that films coming from the German branch can have their German title in the h1-name-tag;
+        # in this case (only?), IMDB renders an additional "originalTitle"-tag.
+        self.o_title = gutils.trim(self.page, '<div class="originalTitle">', '<span')
         if not self.o_title:
-            self.o_title = gutils.regextrim(self.page, '<h1 itemprop="name" class>', '([ ]|[&][#][0-9]+[;])<span')
+            self.o_title = gutils.regextrim(self.page, '<h1 itemprop="name"[^>]*>', '&nbsp;')
+        if not self.o_title:
+            self.o_title = gutils.trim(self.page, 'og:title\' content="', '"')
         if not self.o_title:
             self.o_title = re.sub(' [(].*', '', gutils.trim(self.page, '<title>', '</title>'))
+        self.o_title = gutils.clean(re.sub('"', '', self.o_title))
 
-    def get_title(self):    # same as get_o_title()
-        self.title = gutils.regextrim(self.page, '<h1 itemprop="name" class>', '([ ]|[&][#][0-9]+[;])<span')
+    def get_title(self):
+        # let's try to find the right language version; if not found, the original title succeeds
+        from locale import getdefaultlocale
+        defaultLang, defaultEnc = getdefaultlocale()
+        if defaultLang[:2] == 'cs':
+            self.title = gutils.regextrim(self.release_page,'<td>Czech Republic.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'de':
+            self.title = gutils.regextrim(self.release_page,'<td>Germany.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'es':
+            self.title = gutils.regextrim(self.release_page,'<td>Spain.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'fr':
+            self.title = gutils.regextrim(self.release_page,'<td>France.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'he':
+            self.title = gutils.regextrim(self.release_page,'<td>Israel.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'hu':
+            self.title = gutils.regextrim(self.release_page,'<td>Hungary.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'it':
+            self.title = gutils.regextrim(self.release_page,'<td>Italy.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'pl':
+            self.title = gutils.regextrim(self.release_page,'<td>Poland.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'rm':
+            self.title = gutils.regextrim(self.release_page,'<td>Romania.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'ru':
+            self.title = gutils.regextrim(self.release_page,'<td>Russia.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'sl':
+            self.title = gutils.regextrim(self.release_page,'<td>Slovenia.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'sl':
+            self.title = gutils.regextrim(self.release_page,'<td>Slovakia.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'sr':
+            self.title = gutils.regextrim(self.release_page,'<td>Serbia.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'tk':
+            self.title = gutils.regextrim(self.release_page,'<td>Turkey.*<\/td>\n.*<td>','</td>')
+        elif defaultLang[:2] == 'uk':
+            self.title = gutils.regextrim(self.release_page,'<td>Ukraine.*<\/td>\n.*<td>','</td>')
+
+        if not self.title:
+            self.title = gutils.regextrim(self.page, '<h1>', '([ ]|[&][#][0-9]+[;])<span')
         if not self.title:
             self.title = re.sub(' [(].*', '', gutils.trim(self.page, '<title>', '</title>'))
 
     def get_director(self):
         self.director = ''
-        parts = re.split('<a href=', gutils.trim(self.cast_page, '>Directed by', '</table>'))
+        parts = re.split('<a href=', gutils.trim(self.cast_page, 'Directed by', '</table>'))
         if len(parts) > 1:
             for part in parts[1:]:
-                tempstr = gutils.trim(part, '>', '<')
-                tempstr = tempstr.replace('\n', '')
-                director = tempstr.strip()
+                director = gutils.trim(part, '>', '<')
+                director = director.replace('\n', '')
+                director.strip()
                 self.director = self.director + director + ', '
             self.director = self.director[0:len(self.director) - 2]
 
     def get_plot(self):
-        self.plot = gutils.trim(self.page, '<h2>Storyline</h2>', '</span>')
-        self.plot = gutils.after(self.plot, '<span>    ')
+        plotlist = gutils.trim(self.plot_page, 'id="plot-summaries-content">', '</ul>')
+        plotlist = plotlist.split('<li')
+        plotcompilation = ''
+        for listelement in plotlist:
+            if listelement != '' and not 'It looks like we don\'t have any Plot Summaries for this title yet.' in listelement:
+                plotcompilation = plotcompilation + gutils.trim(listelement, '<p>', '</p>') + '\n'
+                plotcompilation = plotcompilation + re.sub('<[^<]+?>', '', gutils.trim(listelement, '<div class="author-container">', '</div>').replace('\n','').lstrip()) + '\n\n'
+        if plotcompilation != '':
+            self.plot = plotcompilation
+        else:
+            self.plot = gutils.regextrim(self.page, 'itemprop="description"', '<')
+            self.plot = gutils.after(self.plot, '>')
+            elements = self.plot_page.split('<p class="plotpar">')
+            if len(elements) < 2:
+                elements = re.split('<li class="(?:odd|even)">', self.plot_page)
+            if len(elements) > 1:
+                self.plot = self.plot + '\n\n'
+                elements[0] = ''
+                for element in elements[1:]:
+                    if element != '':
+                        self.plot = self.plot + gutils.strip_tags(gutils.before(element, '</a>')) + '\n\n'
 
     def get_year(self):
         self.year = gutils.trim(self.page, '<a href="/year/', '</a>')
@@ -91,11 +153,17 @@ class Plugin(movie.Movie):
                 self.year = tmp.group(0)
 
     def get_runtime(self):
-        self.runtime = gutils.regextrim(self.page, 'Runtime:<[^>]+>', ' min')
+        self.runtime = gutils.strip_tags(gutils.regextrim(self.page, 'Runtime<[^>]+>', 'min<'))
+        tmp = self.runtime.split('h ')
+        if len(tmp)>1:
+            try:
+                self.runtime = int(tmp[0]) * 60 + int(tmp[1])
+            except:
+                None
 
     def get_genre(self):
-        self.genre = gutils.regextrim(self.page, 'Genre[s]*:<[^>]+>', '</div>').replace('\n', '')
-        self.genre = self.__before_more(self.genre)
+        self.genre = gutils.regextrim(self.page, '="genres"[^>]*>', '</div>')
+        self.genre = self.genre.replace('</a><a', '</a>, <a')
 
     def get_cast(self):
         self.cast = ''
@@ -112,8 +180,15 @@ class Plugin(movie.Movie):
         self.cast = re.sub(' \n ', '\n', self.cast)
 
     def get_classification(self):
-        self.classification = gutils.trim(self.page, '(<a href="/mpaa">MPAA</a>)', '</div>')
-        self.classification = gutils.trim(self.classification, 'Rated ', ' ')
+        # until we can find a way to locate the user, we have to use the US-classification
+        self.classification = gutils.trim(self.page, '<meta itemprop="contentRating" content="', '"')
+        if not self.classification:
+            classificationList = gutils.regextrim(self.cert_page,'id="certifications-list"','<\/ul>')
+            if classificationList:
+                self.classification = gutils.regextrim(classificationList,'>United States:','<')
+            else: # the old way
+                self.classification = gutils.trim(self.cert_page, '>Certification:<', '</div>')
+                self.classification = gutils.trim(self.classification, '>USA:', '<')
 
     def get_studio(self):
         self.studio = ''
@@ -121,9 +196,9 @@ class Plugin(movie.Movie):
         tmp = tmp.split('href="')
         if len(tmp)>1:
             for entry in tmp[1:]:
-                tempstr = gutils.trim(entry, '>', '<')
-                tempstr = tempstr.replace('\n', '')
-                entry = tempstr.strip()
+                entry = gutils.trim(entry, '>', '<')
+                entry = entry.replace('\n', '')
+                entry = entry.strip()
                 if entry:
                     self.studio = self.studio + entry + ', '
             if self.studio:
@@ -133,32 +208,23 @@ class Plugin(movie.Movie):
         self.o_site = ''
 
     def get_site(self):
-        self.site = "http://www.imdb.com/title/tt%s" % self.movie_id
+        self.site = "https://www.imdb.com/title/tt%s/" % self.movie_id
 
     def get_trailer(self):
-        self.trailer = "http://www.imdb.com/title/tt%s/trailers" % self.movie_id
+        self.trailer = "https://www.imdb.com/title/tt%s/trailers" % self.movie_id
 
     def get_country(self):
-        self.country = '<' + gutils.trim(self.page, 'Country:<', '</div>')
-        self.country = re.sub('[ ]+', ' ', re.sub('[\n]+', '', self.country))
+        self.country = gutils.after(gutils.trim(self.page, 'country_of_origin', '</a>'), '>')
 
     def get_rating(self):
-#        pattern = re.compile('>([0-9]([.][0-9])*)(<[^>]+>)+[/](<[^>]+>)[0-9][0-9]<')
-#        result = pattern.search(self.page)
-#        if result:
-#            self.rating = result.groups()[0]
-#            if self.rating:
-#                try:
-#                    self.rating = round(float(self.rating), 0)
-#                except Exception, e:
-#                    self.rating = 0
-        tmp = gutils.trim(self.page, '<div class="ratingValue">', '</div>')
-#        image_link = gutils.trim(tmp, '<a href="', '"')
-        poster_page = self.open_page(url='http://www.imdb.com')
-#        tmp = gutils.trim(poster_page, '<div class="photo">', '</div>')
-        self.rating = gutils.trim(tmp, '<span itemprop="ratingValue">', '</span>')
-#        else:
-#            self.rating = 0
+        self.rating = gutils.strip_tags(gutils.trim(self.page, 'IMDb RATING', '</span>'))
+        if self.rating:
+            try:
+                self.rating = round(float(self.rating), 0)
+            except Exception as e:
+                self.rating = 0
+        else:
+            self.rating = 0
 
     def get_notes(self):
         self.notes = ''
@@ -199,14 +265,15 @@ class Plugin(movie.Movie):
         parts = re.split('<a href=', gutils.trim(self.cast_page, '>Writing Credits', '</table>'))
         if len(parts) > 1:
             for part in parts[1:]:
-                tempstr = gutils.trim(part, '>', '<')
-                tempstr = tempstr.replace('\n', '')
-                screenplay = tempstr.strip()
+                screenplay = gutils.trim(part, '>', '<')
+                screenplay = screenplay.replace('\n', '')
+                screenplay = screenplay.strip()
                 if screenplay == 'WGA':
                     continue
                 screenplay = screenplay.replace(' (written by)', '')
                 screenplay = screenplay.replace(' and<', '<')
-                self.screenplay = self.screenplay + screenplay + ', '
+                if screenplay not in self.screenplay:
+                    self.screenplay = self.screenplay + screenplay + ', '
             if len(self.screenplay) > 2:
                 self.screenplay = self.screenplay[0:len(self.screenplay) - 2]
                 self.screenplay = re.sub('[ \t]+', ' ', self.screenplay)
@@ -217,9 +284,9 @@ class Plugin(movie.Movie):
         tmp = tmp.split('href="')
         if len(tmp) > 1:
             for entry in tmp[1:]:
-                tempstr = gutils.trim(entry, '>', '<')
-                tempstr = tempstr.replace('\n', '')
-                entry = tempstr.strip()
+                entry = gutils.trim(entry, '>', '<')
+                entry = entry.replace('\n', '')
+                entry = entry.strip()
                 if entry:
                     self.cameraman = self.cameraman + entry + ', '
             if self.cameraman:
@@ -237,15 +304,15 @@ class SearchPlugin(movie.SearchMovie):
     PATTERN_DIRECT = re.compile(r"""value="/title/tt([0-9]+)""")
 
     def __init__(self):
-        # http://www.imdb.com/List?words=
+        # https://www.imdb.com/List?words=
         # finds every title sorted alphabetically, first results are with a quote at
         # the beginning (episodes from tv series), no popular results at first
-        # http://www.imdb.com/find?more=tt;q=
+        # https://www.imdb.com/find?more=tt;q=
         # finds a whole bunch of results. if you look for "Rocky" you will get 903 results.
-        # http://www.imdb.com/find?s=tt;q=
+        # https://www.imdb.com/find?s=tt;q=
         # seems to give the best results. 88 results for "Rocky", popular titles first.
-        self.original_url_search   = 'http://www.imdb.com/find?s=tt&q='
-        self.translated_url_search = 'http://www.imdb.com/find?s=tt&q='
+        self.original_url_search   = 'https://www.imdb.com/find?s=tt&q='
+        self.translated_url_search = 'https://www.imdb.com/find?s=tt&q='
         self.encode                = 'utf8'
 
     def search(self,parent_window):
@@ -282,8 +349,8 @@ class SearchPluginTest(SearchPlugin):
     # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
     #
     test_configuration = {
-        'Rocky Balboa'         : [ 11, 11 ],
-        'Ein glückliches Jahr' : [ 2, 2 ]
+        'Rocky Balboa'         : [ 10, 10 ],
+        'Ein glückliches Jahr' : [ 3, 3 ]
     }
 
 class PluginTest:
@@ -351,22 +418,18 @@ Lucy Speed' + _(' as ') + 'Second Whore\n\
 Patricia Potter' + _(' as ') + 'Third Whore\n\
 John Ramm' + _(' as ') + 'Makepeace\'s Neighbor\n\
 Martin Neely' + _(' as ') + 'Paris / Lady Montague (as Martin Neeley)\n\
-The Choir of St. George\'s School in Windsor' + _(' as ') + '(as The Choir of St. George\'s School Windsor)\n\
-Rest of cast listed alphabetically:\n\
- Carlisle Antonio' + _(' as ') + 'Indian (uncredited)\n\
-Steve Apelt' + _(' as ') + 'Theatregoer (uncredited)\n\
+The Choir of St. George\'s School in Windsor' + _(' as ') + 'Choir (as The Choir of St. George\'s School Windsor) rest of cast listed alphabetically:\n\
 Jason Canning' + _(' as ') + 'Nobleman (uncredited)\n\
-Matthew Christian' + _(' as ') + 'Queen Elizabeth I Party Guest (uncredited)\n\
 Kelley Costigan' + _(' as ') + 'Theatregoer (uncredited)\n\
 Rupert Everett' + _(' as ') + 'Christopher Marlowe (uncredited)\n\
-John Inman' + _(' as ') + 'Lady Capulet in play (uncredited)',
+John Inman' + _(' as ') + 'Character Player (uncredited)',
             'country'           : 'USA',
-            'genre'             : 'Comedy | Drama | History | Romance',
+            'genre'             : 'Comedy | Drama | Romance',
             'classification'    : False,
-            'studio'            : 'Universal Pictures, Miramax, Bedford Falls Company, The',
+            'studio'            : 'Universal Pictures, Miramax Films, Bedford Falls Productions',
             'o_site'            : False,
-            'site'              : 'http://www.imdb.com/title/tt0138097',
-            'trailer'           : 'http://www.imdb.com/title/tt0138097/trailers',
+            'site'              : 'https://www.imdb.com/title/tt0138097/',
+            'trailer'           : 'https://www.imdb.com/title/tt0138097/trailers',
             'year'              : 1998,
             'notes'             : _('Language') + ': English\n'\
 + _('Audio') + ': Dolby Digital\n'\
