@@ -22,8 +22,8 @@ __revision__ = '$Id$'
 # GNU General Public License, version 2 or later
 
 pname = 'Griffith'
-pversion = '0.17'
-pauthor = 'Vasco Nunes, Piotr Ożarowski <griffith@griffith.cc>, Dan Johansen'
+pversion = '0.19'
+pauthor = 'Vasco Nunes, Piotr Ożarowski <griffith@griffith.cc>, Dan Johansen <strit@strits.dk>'
 pyear = '2005-2021'
 pwebsite = 'https://gitlab.com/Strit/griffith/'
 pdescription = _('Griffith is a film collection manager.')
